(format-query
query
&
{:keys [pretty? validate? spec-ed? force-iris?]
:or {pretty? false validate? true spec-ed? false force-iris? false}})Format query into a SPARQL Query string. Throws an exception if query
does not conform to spec or otherwise fails validation.
Format `query` into a SPARQL Query string. Throws an exception if `query` does not conform to spec or otherwise fails validation.
(format-update
update
&
{:keys [pretty? validate? spec-ed? force-iris?]
:or {pretty? false validate? true spec-ed? false force-iris? false}})Format update into a SPARQL Update string. Throws an exception if update
does not conform to spec or otherwise fails validation.
Format `update` into a SPARQL Update string. Throws an exception if `update` does not conform to spec or otherwise fails validation.
(format-updates
updates
&
{:keys [pretty? validate? spec-ed? force-iris?]
:or {pretty? false validate? true spec-ed? false force-iris? false}})Format the coll updates into a SPARQL Update Request string. Throws
an exception if any update does not conform to spec or otherwise
fails validation.
Format the coll `updates` into a SPARQL Update Request string. Throws an exception if any update does not conform to spec or otherwise fails validation.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |