Namespace for formatting error messages and other error utils.
Namespace for formatting error messages and other error utils.
(prefix-error-msg prefix-errs)(prefix-error-msg prefix-errs index)Return an error message specifying the number of unexpandable IRIs, missing prefixes and, if applicable, the input coll index.
Return an error message specifying the number of unexpandable IRIs, missing prefixes and, if applicable, the input coll index.
(scope-error-msg scope-errs)(scope-error-msg scope-errs index)Return an error message specifying the number of variables with scope errors, number of locations and, if applicable, the input coll index.
Return an error message specifying the number of variables with scope errors, number of locations and, if applicable, the input coll index.
(spec-error-keywords spec-ed)Return a vector of keywords describing each failing clause.
Return a vector of keywords describing each failing clause.
(spec-error-msg spec-ed)(spec-error-msg spec-ed index)Return an error message specifying the invalid clauses and, if applicable, the input coll index.
Return an error message specifying the invalid clauses and, if applicable, the input coll index.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |