(bracketted-or-fn-expr-str? s)Determine if a expression string represents a bracketted expression or a function call.
Determine if a expression string represents a bracketted expression or a function call.
(format-ast ast opts)Convert ast into a string, with opts including:
:xsd-prefix the prefix of the XSD IRI, used in RDF literals.:pretty? whether to add linebreaks or indents.Convert `ast` into a string, with `opts` including: - `:xsd-prefix` the prefix of the XSD IRI, used in RDF literals. - `:pretty?` whether to add linebreaks or indents.
Convert the AST node into a string.
Convert the AST node into a string.
(indent-str s)Add 4 spaces after each line break (including at the beginning).
Add 4 spaces after each line break (including at the beginning).
(join-clauses clauses pretty?)Join the clauses coll. If pretty? is true, separate by line
breaks; otherwise separate by space.
Join the `clauses` coll. If `pretty?` is true, separate by line breaks; otherwise separate by space.
(wrap-in-braces clause pretty?)Wrap the clause string in curly braces. If pretty? is true,
also add line breaks and indent clause.
Wrap the `clause` string in curly braces. If `pretty?` is true, also add line breaks and indent `clause`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |