All platforms.

com.yetanalytics.flint.spec


sparql-keysclj/smacro

(sparql-keys &
             {:keys [key-comp-fn req opt req-un opt-un]
              :or {key-comp-fn compare}})

A variant of s/keys that automatically conforms the map into a kv-pair vector sorted by key-comp-fn. In addition, keys are restricted to those in the spec.

A variant of `s/keys` that automatically conforms the map into
a kv-pair vector sorted by `key-comp-fn`. In addition, keys
are restricted to those in the spec.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries