Like expr-spec-mm, but covers also covers aggregate expressions.
Like `expr-spec-mm`, but covers also covers aggregate expressions.
A set of all operations used in aggregate expressions.
A set of all operations used in aggregate expressions.
(defexprspecs mm-name syms expr-spec)Macro to repeatedly define (defmethod mm-name 'sym [_] expr-spec).
Macro to repeatedly define `(defmethod mm-name 'sym [_] expr-spec)`.
Given a Flint expr list, returns a spec determined by its first arg.
Given a Flint expr list, returns a spec determined by its first arg.
(keyword-args & kspecs)Given kspecs (e.g. (keyword-args ::distinct? ::selector)), return
a regex spec that can be used to spec a sequence of :keyword value
pairs (e.g. (:distinct? true :selector ";")).
Given `kspecs` (e.g. `(keyword-args ::distinct? ::selector)`), return a regex spec that can be used to spec a sequence of `:keyword value` pairs (e.g. `(:distinct? true :selector ";")`).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |