Accepts a special WHERE form/graph pattern in the form [:keyword ...]
and returns the appropriate regex spec. The spec applies an additional
conformer in order to allow for identification during formatting.
Accepts a special WHERE form/graph pattern in the form `[:keyword ...]` and returns the appropriate regex spec. The spec applies an additional conformer in order to allow for identification during formatting.
Specs for special WHERE forms/graph patterns, which should be
of the form [:keyword ...].
Specs for special WHERE forms/graph patterns, which should be of the form `[:keyword ...]`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |