(validate-bnodes node-m)(validate-bnodes prev-bnodes node-m)Given the map node-m between nodes and zipper locs, validate that
all bnodes satisfy the following conditions:
Returns a pair between the union of prev-bnodes and the bnodes in
node-m, and a nilable error map.
Given the map `node-m` between nodes and zipper locs, validate that all bnodes satisfy the following conditions: - They cannot be duplicated in different Basic Graph Patterns (BGPs). - They cannot be duplicated across different Updates in a request. Returns a pair between the union of `prev-bnodes` and the bnodes in `node-m`, and a nilable error map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |