com.yetanalytics.flint.validate.variable


distinct-varsclj/s

(distinct-vars vars)

Return the distinct variables in vars, comparing their SPARQL names while retaining the first encountered representation of each variable.

Return the distinct variables in `vars`, comparing their SPARQL names while
retaining the first encountered representation of each variable.
sourceraw docstring

get-expr-varsclj/smultimethod

Return all the variables in an expression.

Return all the variables in an expression.
sourceraw docstring

get-scope-varsclj/smultimethod

Return a coll of all variables in the scope of the AST branch.

Return a coll of all variables in the scope of the AST branch.
sourceraw docstring

group-by-projected-varsclj/smultimethod

Return a coll of vars that are projected in a GROUP BY clause (i.e. all vars not contained within an expression.)

Return a coll of vars that are projected in a GROUP BY clause (i.e.
all vars not contained within an expression.)
sourceraw docstring

invalid-agg-expr-varsclj/smultimethod

Return a coll of invalid aggregate variables in an expression.

Return a coll of invalid aggregate variables in an expression.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries